# AUTOMATICALLY GENERATED by `shtab`



complete vcspull \
        'c/--/(all any color detailed dry-run exit-on-error fetch field file fixed-strings help ignore-case include-worktrees invert-match json log-level long max-concurrent name ndjson no-concurrent no-merge offline recursive relative-paths sequential show-unchanged smart-case summary-only tree url verbose version word-regexp workspace workspace-root write yes)/' \
        'c/-/(- F S V a d f h i n r v w x y)/' \
        'n/-f/f/' \
        'n/--file/f/' \
        'n/--color/(auto always never)/' \
        'n/--color/(auto always never)/' \
        'n/--color/(auto always never)/' \
        'n/--color/(auto always never)/' \
        'p/1/(sync list status search add discover fmt import worktree)/' \
        'p@2@`set cmd=($COMMAND_LINE); ( [ "$cmd[2]" == "import" ] && echo 'github' 'gh' 'gitlab' 'gl' 'codeberg' 'cb' 'gitea' 'forgejo' 'codecommit' 'cc' 'aws' || false ) || ( [ "$cmd[2]" == "worktree" ] && echo 'list' 'sync' 'prune' || false )`@' \
        'p/*/()/'
